Learn R Programming

cancerGI (version 1.0.0)

cancerGI-package: Statistical Analyses of Genetic Interactions in Cancer

Description

This package contains statistical analyses performed in Wang, Fu, et al. (2014) for the genomic data from the TCGA breast cancer patients, as well as for the RNAi knockdown data.

Arguments

Author

Audrey Qiuyan Fu, Xiaoyue Wang

Maintainer: Audrey Fu <audreyqyfu@gmail.com>

Details

Package:cancerGI
Type:Package
Version:1.0
Date:2015-04-19
License:What license is it under?

References

Wang, X., Fu, A. Q., McNerney, M. and White, K. P. (2014). Widespread genetic epistasis among breast cancer genes. Nature Communications. 5 4828. doi: 10.1038/ncomms5828

See Also

RNAi testMutationalPatternAll.wrapper computeSurvivalPValueForGenePairSet.output computeSmallWorldness