- file.out
Output filename.
- gene.pairs
Matrix of two columns, which are gene names.
- data.mut
Integer matrix of genes by cases. The first column contains gene names. Each of the other columns contains mutation patterns of a case: 0 as wildtype, 1 amplification and -1 deletion.
- data.surv
Data frame containing case ID, survival time and survival status. Cases do not need to match those in data.mut.
- colTime
Scalar indicating which column in data.surv contains the survival time.
- colStatus
A character string indicating which column in data.surv contains the survival status: "DECEASED" or "LIVING".
- type.gene1
Integer indicating the type of mutation: 0 for wild type, 1 for amplification, and -1 for deletion.
- type.gene2
Same as type.gene1, but for the second gene.
- groups
"All" if comparing all combinations: wildtype & wildtype, wild type & mutated, both mutated; or "Two", if only comparing single mutation and double mutation.
- PRINT
Default is FALSE. Prints intermediate values if set to TRUE. Output may be massive if the number of gene pairs is large.
- PRINT.INDEX
Default is FALSE. Unused.