This function performs survival analysis, similar to function
computeSurvivalPValueForGenePairSet.output, but for one pair of genes.
computeSurvivalPValueOneGenePair(data.mut, data.surv,
colTime = 2, colStatus = 3,
type.gene1 = (-1), type.gene2 = (-1),
groups = c("All", "Two"),
compare = c("Both", "Gene1", "Gene2"),
PLOT = FALSE, PRINT = FALSE,
pvalue.text.x = 10, pvalue.text.y = 0.1,
legend.x = 150, legend.y = 1)The output contains the same info as described in computeSurvivalPValueForGenePairSet.output.
Integer matrix of individuals by two genes. Each column containing the mutation patterns of multiple genes: 0 as wildtype, 1 amplification and -1 deletion.
Data frame containing case ID, survival time and survival status. Cases should match those in data.mut.
Scalar indicating which column in data.surv contains the survival time.
A character string indicating which column in data.surv contains the survival status: "DECEASED" or "LIVING".
Integer indicating the type of mutation: 0 for wild type, 1 for amplification, and -1 for deletion.
Same as type.gene1, but for the second gene.
"All" if comparing all combinations: wildtype & wildtype, wild type & mutated, both mutated; or "Two", if only comparing single mutation and double mutation.
"Both" if comparing all four combinations: wildtype & wildtype, wildtype & mutated, mutated & wildtype, and mutated & mutated. "Gene1" if comparing three combinations: gene1 wildtype, gene1 mutated & gene2 wildtype, and both mutated. "Gene2" is similar to "Gene1".
If TRUE, plot the survival curves and print the p value onto the plot. Location of the p value legend is controlled by pvalue.text.x and pvalue.text.y described below.
If TRUE, print intermediate values.
The x coordinate of the p value legend in plot.
The y coordinate of the p value legend in plot.
The x coordinate of the curve legend in plot.
The y coordinate of the curve legend in plot.
Audrey Q. Fu, Xiaoyue Wang
Wang, X., Fu, A. Q., McNerney, M. and White, K. P. (2014). Widespread genetic epistasis among breast cancer genes. Nature Communications. 5 4828. doi: 10.1038/ncomms5828
computeSurvivalPValueForGenePairSet.output