This function is similar to computeSurvivalPValueOneGenePair, except that it writes the analysis results directly to output file and does not allow for plotting the survival curves.
computeSurvivalPValueOneGenePair.output(file.out, genes.info,
data.mut, data.surv, colTime = 2, colStatus = 3,
groups = c("All", "Two"), PRINT = FALSE)A vector of values from the survival analysis, as described in computeSurvivalPValueForGenePairSet.output
Output filename.
A vector of 6 elements: gene1, mutation type, gene2, mutation type, gene1's column index in data.mut, gene2's column index in data.mut.
Integer matrix of genes by cases. The first column contains gene names. Each of the other columns contains mutation patterns of a case: 0 as wildtype, 1 amplification and -1 deletion.
Data frame containing case ID, survival time and survival status. Cases should match those in data.mut.
Scalar indicating which column in data.surv contains the survival time.
A character string indicating which column in data.surv contains the survival status: "DECEASED" or "LIVING".
"All" if comparing all combinations: wildtype & wildtype, wild type & mutated, both mutated; or "Two", if only comparing single mutation and double mutation.
Default is FALSE. Prints intermediate values if set to TRUE. Output may be massive if the number of gene pairs is large.
Audrey Q. Fu, Xiaoyue Wang
Wang, X., Fu, A. Q., McNerney, M. and White, K. P. (2014). Widespread genetic epistasis among breast cancer genes. Nature Communications. 5 4828. doi: 10.1038/ncomms5828
computeSurvivalPValueForGenePairSet.output