Learn R Programming

cancerGI (version 1.0.0)

mutations: Genetic mutation data in patients.

Description

Data frame that contains mutation patterns in multiple genes across multiple patients.

Arguments

Format

A data frame with 85 rows and 951 columns. Each row is a gene. The first column contains gene names, and each of the other columns contains the mutation pattern in an individual: 0 for no mutation, 1 amplification and -1 deletion.

References

Wang, X., Fu, A. Q., McNerney, M. and White, K. P. (2014). Widespread genetic epistasis among breast cancer genes. Nature Communications. 5 4828. doi: 10.1038/ncomms5828.

Examples

Run this code
data(mutations)

Run the code above in your browser using DataLab